==> bigloo3.1a.tar.gz: bigloo3.1a/comptime/Reduce/walk.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Reduce/walk.scm             */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Thu Jul 13 10:25:23 1995                          */
;*    Last change :  Wed Oct 26 08:41:04 2005 (serrano)                */
;*    Copyright   :  1995-2005 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    The Reduction optimizations                                      */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module reduce_walk
   (include "Engine/pass.sch")
   (import  tools_shape
	    tools_error
	    engine_param
	    type_type
	    ast_var
	    ast_node
	    reduce_copy
	    reduce_cse
	    reduce_cond
	    reduce_typec
	    reduce_flow-typec
	    reduce_1occ
	    reduce_beta
	    ast_remove)
   (export  (reduce-walk! globals . obj)))

;*---------------------------------------------------------------------*/
;*    reduce-walk ...                                                  */
;*---------------------------------------------------------------------*/
(define (reduce-walk! globals . type-unsafe)
   (cond
      ((and (pair? type-unsafe) (car type-unsafe))
       (pass-prelude "Reduction (trivial)")
       (reduce-1occ! globals)
       (pass-postlude (remove-var 'reduce globals)))
      (*optim-dataflow?*
       (pass-prelude "Reduction")
       (reduce-copy! globals)
       (when (>=fx *optim* 2) (reduce-cse! globals))
       (reduce-type-check! globals)
       (reduce-copy! globals)
       (reduce-conditional! globals)
       (reduce-1occ! globals)
       (when *optim-reduce-beta?* (reduce-beta! globals))
       (reduce-flow-type-check! globals)
       (pass-postlude (remove-var 'reduce globals)))
      (else
       (remove-var 'reduce globals))))

==> bigloo4.0a.tar.gz: bigloo4.0a/comptime/Reduce/walk.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Reduce/walk.scm             */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Thu Jul 13 10:25:23 1995                          */
;*    Last change :  Tue Sep  7 09:28:00 2010 (serrano)                */
;*    Copyright   :  1995-2010 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    The Reduction optimizations                                      */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module reduce_walk
   (include "Engine/pass.sch")
   (import  tools_shape
	    tools_error
	    engine_param
	    type_type
	    ast_var
	    ast_node
	    reduce_copy
	    reduce_cse
	    reduce_cond
	    reduce_typec
	    reduce_flow-typec
	    reduce_1occ
	    reduce_beta
	    ast_remove)
   (export  (reduce-walk! globals::pair-nil msg::bstring . obj)))

;*---------------------------------------------------------------------*/
;*    reduce-walk ...                                                  */
;*---------------------------------------------------------------------*/
(define (reduce-walk! globals msg . type-unsafe)
   (pass-prelude msg)
   (cond
      ((and (pair? type-unsafe) (car type-unsafe))
       (reduce-1occ! globals)
       (pass-postlude (remove-var 'reduce globals)))
      (*optim-dataflow?*
       (reduce-copy! globals)
       (when (>=fx *optim* 2) (reduce-cse! globals))
       (reduce-type-check! globals)
       (reduce-copy! globals)
       (reduce-conditional! globals)
       (reduce-1occ! globals)
       (when *optim-reduce-beta?* (reduce-beta! globals))
       (reduce-flow-type-check! globals)
       (pass-postlude (remove-var 'reduce globals)))
      (else
       (remove-var 'reduce globals))))
